[ARVADOS-DEV] updated: 11339c91b5e7efdc214897856b103d0c532df45e

git at public.curoverse.com git at public.curoverse.com
Sat Feb 7 04:56:06 EST 2015


Summary of changes:
 jenkins/run-build-packages.sh | 11 ++++++++++-
 1 file changed, 10 insertions(+), 1 deletion(-)

       via  11339c91b5e7efdc214897856b103d0c532df45e (commit)
      from  d7f1a63c8396715e501be04addefb0a158303e69 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 11339c91b5e7efdc214897856b103d0c532df45e
Author: Tom Clegg <tom at curoverse.com>
Date:   Sat Feb 7 04:56:15 2015 -0500

    Use virtualenv to get a newer setuptools that doesn't munge Python versions. No issue #

diff --git a/jenkins/run-build-packages.sh b/jenkins/run-build-packages.sh
index 1dae4bc..cdf1d17 100755
--- a/jenkins/run-build-packages.sh
+++ b/jenkins/run-build-packages.sh
@@ -85,6 +85,14 @@ if [[ "$DEBUG" != 0 ]]; then
   echo "Workspace is $WORKSPACE"
 fi
 
+# We need a recent setuptools. Older ones replace + with - in our
+# version numbers, making them non-PEP-440-compliant and
+# non-uploadable.
+VENV=$(mktemp -d)
+echo "Using virtualenv $VENV"
+virtualenv "$VENV"
+. "$VENV/bin/activate"
+
 version_from_git() {
   # Generates a version number from the git log for the current working
   # directory, and writes it to stdout.
@@ -477,7 +485,8 @@ else
   fi
 fi
 
 # clean up temporary GOPATH
 rm -rf "$GOPATH"
+rm -rf "$VENV"
 
 exit $EXITCODE

-----------------------------------------------------------------------
@@ -477,7 +485,8 @@ else
 fi
 
-# clean up temporary GOPATH
+# clean up temporary GOPATH and VENV
 rm -rf "$GOPATH"


hooks/post-receive
-- 




More information about the arvados-commits mailing list